<?php if ($is_message) : ?>
    <?php if ($is_message_success) : ?>
        <p class="success"><?= $this->lang->line('Your password successfully changed') ?></p>
    <?php else : ?>
        <p class="fail"><?= $this->lang->line('Error, try again') ?></p>
    <?php endif; ?>
<?php endif; ?>
<?= form_open('', array('class' => 'form_register')) ?>
<div class="field-box">
    <label><?= $this->lang->line('Current password') ?></label>
    <input type="password" name="oldpass" value="" required />
    <?= form_error('oldpass'); ?>
</div>
<div class="field-box">
    <label><?= $this->lang->line('New password') ?></label>
    <input type="password" name="password" value="" required />
    <?= form_error('password'); ?>
</div>
<div class="field-box">
    <label><?= $this->lang->line('New password again') ?></label>
    <input type="password" name="passconf" value="" required />
    <?= form_error('passconf'); ?>
</div>
<div class="field-box">                            
    <input type="submit" class="big_orange" value="<?= $this->lang->line('Change password') ?>" />
    <a href="" class="cancel_link"><?= $this->lang->line('Cancel') ?></a>
</div>
<?= form_close() ?>